@@ -18,6 +18,7 @@ from django.utils.safestring import mark_safe
 from django.utils.translation import get_language
 from django.template.loader import get_template
 from django.template.context import Context
+from django.utils.translation import ugettext as _
 
 # grappelli imports
 from grappelli.settings import ADMIN_TITLE, ADMIN_URL, SWITCH_USER, SWITCH_USER_ORIGINAL, SWITCH_USER_TARGET, CLEAN_INPUT_TYPES
@@ -55,6 +56,15 @@ def get_admin_title():
     return ADMIN_TITLE
 
 
+# SITE_TITLE
+@register.simple_tag
+def get_site_title():
+    """
+    Returns the Title for the Admin-Interface.
+    """
+    return ADMIN_TITLE or _("Django site admin")
+
+
 # RETURNS CURRENT LANGUAGE
 @register.simple_tag
 def get_lang():
